==> spreadsheets-8.x-1.4.tar.gz: spreadsheets/src/Form/GoogleSheetsConfigForm.php <==
<?php

namespace Drupal\spreadsheets\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Configure javali_googlesheets settings for this site.
 */
class GoogleSheetsconfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'spreadsheets_google_sheets_config';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'spreadsheets.google_sheets_config',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $credentialsConfig = \Drupal::config('spreadsheets.spreadsheetscredentials');

    $tokenPath = \Drupal::service('file_system')->realpath('private://token.json');
    if (empty($credentialsConfig->get('credentials_file')) || !file_exists($tokenPath)) {
      $url = Url::fromRoute('spreadsheets.spreadsheets_credentials')->toString();
      $form['warning'] = [
        '#markup' => 'Please <a href="' . $url . '" target="_blank">setup your api credentials </a>
      to use this module',
      ];
      return $form;
    }

    $config = $this->config('spreadsheets.google_sheets_config');

    $form['sheet_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Insert Sheet id here'),
      '#required' => TRUE,
      '#default_value' => $config->get('sheet_id'),
    ];

    $form['sheet_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Insert Sheet Name here'),
      '#description' => ('format ex: Sheet1'),
      '#default_value' => $config->get('sheet_name'),
      '#required' => TRUE,
    ];

    $form['range'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Insert Range here here'),
      '#description' => ('format ex: A1:C2'),
      '#required' => TRUE,
      '#default_value' => $config->get('range'),
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::service('config.factory')->getEditable('spreadsheets.google_sheets_config');
    $config->set('sheet_id', $form_state->getValue('sheet_id'));
    $config->set('range', $form_state->getValue('range'));
    $config->set('sheet_name', $form_state->getValue('sheet_name'));
    $config->save();
    $messenger = \Drupal::messenger();
    $messenger->addStatus($this->t('The Configuration has been saved'));
  }

}

==> spreadsheets-8.x-1.33.tar.gz: spreadsheets/src/Form/GoogleSheetsConfigForm.php <==
<?php

namespace Drupal\spreadsheets\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Configure javali_googlesheets settings for this site.
 */
class GoogleSheetsConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'spreadsheets_google_sheets_config';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'spreadsheets.google_sheets_config',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $credentialsConfig = \Drupal::config('spreadsheets.spreadsheetscredentials');

    $tokenPath = \Drupal::service('file_system')->realpath('private://token.json');
    if (empty($credentialsConfig->get('credentials_file')) || !file_exists($tokenPath)) {
      $url = Url::fromRoute('spreadsheets.spreadsheets_credentials')->toString();
      $form['warning'] = [
        '#markup' => 'Please <a href="' . $url . '" target="_blank">setup your api credentials </a>
      to use this module',
      ];
      return $form;
    }

    $config = $this->config('spreadsheets.google_sheets_config');

    $form['sheet_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Insert Sheet id here'),
      '#required' => TRUE,
      '#default_value' => $config->get('sheet_id'),
    ];

    $form['sheet_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Insert Sheet Name here'),
      '#description' => ('format ex: Sheet1'),
      '#default_value' => $config->get('sheet_name'),
      '#required' => TRUE,
    ];

    $form['range'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Insert Range here here'),
      '#description' => ('format ex: A1:C2'),
      '#required' => TRUE,
      '#default_value' => $config->get('range'),
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::service('config.factory')->getEditable('spreadsheets.google_sheets_config');
    $config->set('sheet_id', $form_state->getValue('sheet_id'));
    $config->set('range', $form_state->getValue('range'));
    $config->set('sheet_name', $form_state->getValue('sheet_name'));
    $config->save();
    $messenger = \Drupal::messenger();
    $messenger->addStatus($this->t('The Configuration has been saved'));
  }

}
